@@ -268,7 +268,7 @@ This function preserves point and mark."
 (defun fsharp-in-literal-p (&optional lim)
   "Return non-nil if point is in a Fsharp literal (a comment or
 string). The return value is specifically one of the symbols
-'comment or 'string. Optional argument LIM indicates the
+\\='comment or \\='string. Optional argument LIM indicates the
 beginning of the containing form, i.e. the limit on how far back
 to scan."
   ;; NOTE: Watch out for infinite recursion between this function and
@@ -766,6 +766,10 @@ dedenting."
            (open-bracket-pos (fsharp-nesting-level)))
 
       (cond
+       ((and open-bracket-pos (eq (and (looking-back "[[:space:]\n\r]+" nil t)
+				       (match-beginning 0))
+				  (1+ open-bracket-pos)))
+	fsharp-indent-offset)
        ;; Continuation Lines
        ((fsharp-continuation-line-p)
         (if open-bracket-pos
